==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/Credentials.h <==
// public class gnu.java.net.protocol.http.Credentials

// class file dependencies
// @dep_class 4e57e7668ee9620c gnu_java_net_protocol_http_Credentials
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_Credentials_H_
#define _JC_gnu_java_net_protocol_http_Credentials_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_Credentials$sub_refs	_jc_gnu_java_net_protocol_http_Credentials$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_Credentials$sub_nonrefs	_jc_gnu_java_net_protocol_http_Credentials$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Credentials$refs	_jc_gnu_java_net_protocol_http_Credentials$refs;
typedef struct _jc_gnu_java_net_protocol_http_Credentials$nonrefs	_jc_gnu_java_net_protocol_http_Credentials$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Credentials$object	_jc_gnu_java_net_protocol_http_Credentials$object;

typedef const struct _jc_gnu_java_net_protocol_http_Credentials$vmethods	_jc_gnu_java_net_protocol_http_Credentials$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_Credentials$vtable	_jc_gnu_java_net_protocol_http_Credentials$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_Credentials$vtype	_jc_gnu_java_net_protocol_http_Credentials$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_Credentials$method$_init$a34354cd9552963f(_jc_env *, struct _jc_gnu_java_net_protocol_http_Credentials$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_http_Credentials$method$getPassword$32d96361835935c6(_jc_env *, struct _jc_gnu_java_net_protocol_http_Credentials$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_http_Credentials$method$getUsername$3aabb4fed0b6ee73(_jc_env *, struct _jc_gnu_java_net_protocol_http_Credentials$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_Credentials$method_info$getPassword$32d96361835935c6;
extern _jc_method _jc_gnu_java_net_protocol_http_Credentials$method_info$getUsername$3aabb4fed0b6ee73;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_Credentials$vmethods {
	struct _jc_java_lang_String$object	*(*getPassword$32d96361835935c6)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Credentials$object *);
	struct _jc_java_lang_String$object	*(*getUsername$3aabb4fed0b6ee73)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Credentials$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_Credentials$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_Credentials$vmethods	gnu_java_net_protocol_http_Credentials;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_Credentials$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_Credentials$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Credentials$sub_refs {
	struct _jc_java_lang_String$object	*username;
	struct _jc_java_lang_String$object	*password;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Credentials$refs {
    _jc_gnu_java_net_protocol_http_Credentials$sub_refs	gnu_java_net_protocol_http_Credentials;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Credentials$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Credentials$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_Credentials$sub_nonrefs	gnu_java_net_protocol_http_Credentials;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_Credentials$object {
	_jc_gnu_java_net_protocol_http_Credentials$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_Credentials$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_Credentials$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_Credentials$vtype _jc_gnu_java_net_protocol_http_Credentials$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_Credentials, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_Credentials$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_Credentials_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/http/Credentials.h <==
// public class gnu.java.net.protocol.http.Credentials

// class file dependencies
// @dep_class 4e57e7668ee9620c gnu_java_net_protocol_http_Credentials
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_Credentials_H_
#define _JC_gnu_java_net_protocol_http_Credentials_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_Credentials$sub_refs	_jc_gnu_java_net_protocol_http_Credentials$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_Credentials$sub_nonrefs	_jc_gnu_java_net_protocol_http_Credentials$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Credentials$refs	_jc_gnu_java_net_protocol_http_Credentials$refs;
typedef struct _jc_gnu_java_net_protocol_http_Credentials$nonrefs	_jc_gnu_java_net_protocol_http_Credentials$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Credentials$object	_jc_gnu_java_net_protocol_http_Credentials$object;

typedef const struct _jc_gnu_java_net_protocol_http_Credentials$vmethods	_jc_gnu_java_net_protocol_http_Credentials$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_Credentials$vtable	_jc_gnu_java_net_protocol_http_Credentials$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_Credentials$vtype	_jc_gnu_java_net_protocol_http_Credentials$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_Credentials$method$_init$a34354cd9552963f(_jc_env *, struct _jc_gnu_java_net_protocol_http_Credentials$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_http_Credentials$method$getPassword$32d96361835935c6(_jc_env *, struct _jc_gnu_java_net_protocol_http_Credentials$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_http_Credentials$method$getUsername$3aabb4fed0b6ee73(_jc_env *, struct _jc_gnu_java_net_protocol_http_Credentials$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_Credentials$method_info$getPassword$32d96361835935c6;
extern _jc_method _jc_gnu_java_net_protocol_http_Credentials$method_info$getUsername$3aabb4fed0b6ee73;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_Credentials$vmethods {
	struct _jc_java_lang_String$object	*(*getPassword$32d96361835935c6)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Credentials$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getUsername$3aabb4fed0b6ee73)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Credentials$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_Credentials$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_Credentials$vmethods	gnu_java_net_protocol_http_Credentials;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_Credentials$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_Credentials$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Credentials$sub_refs {
	struct _jc_java_lang_String$object	*username;
	struct _jc_java_lang_String$object	*password;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Credentials$refs {
    _jc_gnu_java_net_protocol_http_Credentials$sub_refs	gnu_java_net_protocol_http_Credentials;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Credentials$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Credentials$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_Credentials$sub_nonrefs	gnu_java_net_protocol_http_Credentials;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_Credentials$object {
	_jc_gnu_java_net_protocol_http_Credentials$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_Credentials$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_Credentials$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_Credentials$vtype _jc_gnu_java_net_protocol_http_Credentials$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_Credentials, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_Credentials$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_Credentials_H_ */
